@@ -26,7 +26,7 @@ def apply_to_mask(f, clip, *a, **k):
         the clip created with f """
         
     newclip = f(clip, *a, **k)
-    if hasattr(newclip, 'mask') and (newclip.mask != None):
+    if hasattr(newclip, 'mask') and (newclip.mask is not None):
         newclip.mask = f(newclip.mask, *a, **k)
     return newclip
 
@@ -38,7 +38,7 @@ def apply_to_audio(f, clip, *a, **k):
         the clip created with f """
         
     newclip = f(clip, *a, **k)
-    if hasattr(newclip, 'audio') and (newclip.audio != None):
+    if hasattr(newclip, 'audio') and (newclip.audio is not None):
         newclip.audio = f(newclip.audio, *a, **k)
     return newclip
 
@@ -65,7 +65,7 @@ def audio_video_fx(f, clip, *a, **k):
     
     if hasattr(clip, "audio"):
         newclip = clip.copy()
-        if clip.audio != None:
+        if clip.audio is not None:
             newclip.audio =  f(clip.audio, *a, **k)
         return newclip
     else:
@@ -80,7 +80,7 @@ def preprocess_args(fun,varnames):
             func_code = f.__code__ # Python 3
             
         names = func_code.co_varnames
-        new_a = [cvsecs(arg) if (name in varnames) else arg
+        new_a = [fun(arg) if (name in varnames) else arg
                  for (arg, name) in zip(a, names)]
         new_kw = {k: fun(v) if k in varnames else v
                  for (k,v) in kw.items()}
@@ -99,4 +99,36 @@ def add_mask_if_none(f, clip, *a, **k):
     """ Add a mask to the clip if there is none. """        
     if clip.mask is None:
         clip = clip.add_mask()
-    return f(clip, *a, **k)
\ No newline at end of file
+    return f(clip, *a, **k)
+
+
+
+@decorator.decorator
+def use_clip_fps_by_default(f, clip, *a, **k):
+    
+    def fun(fps):
+        if fps is not None:
+            return fps
+        else:
+            if hasattr(clip, 'fps') and clip.fps is not None:
+                return clip.fps
+            else:
+                raise AttributeError("No 'fps' (frames per second) attribute specified"
+                " for function %s and the clip has no 'fps' attribute. Either"
+                " provide e.g. fps=24 in the arguments of the function, or define"
+                " the clip's fps with `clip.fps=24`"%f.__name__)
+
+
+    if hasattr(f, "func_code"):
+        func_code = f.func_code # Python 2
+    else:
+        func_code = f.__code__ # Python 3
+        
+    names = func_code.co_varnames[1:]
+    
+    new_a = [fun(arg) if (name=='fps') else arg
+             for (arg, name) in zip(a, names)]
+    new_kw = {k: fun(v) if k=='fps' else v
+             for (k,v) in k.items()}
+
+    return f(clip, *new_a, **new_kw)
