@@ -34,7 +34,8 @@ from ..decorators import (apply_to_mask,
                           outplace,
                           add_mask_if_none,
                           convert_to_seconds,
-                          convert_masks_to_RGB)
+                          convert_masks_to_RGB,
+                          use_clip_fps_by_default)
 
 import os
 try:
@@ -144,8 +145,9 @@ class VideoClip(Clip):
 
 
     @requires_duration
+    @use_clip_fps_by_default
     @convert_masks_to_RGB
-    def write_videofile(self, filename, fps=24, codec=None,
+    def write_videofile(self, filename, fps=None, codec=None,
                         bitrate=None, audio=True, audio_fps=44100,
                         preset="medium",
                         audio_nbytes=4, audio_codec=None,
@@ -166,7 +168,8 @@ class VideoClip(Clip):
           or simply be '.avi' (which will work with any codec).
 
         fps
-          Number of frames per second in the resulting video file.
+          Number of frames per second in the resulting video file. If None is
+          provided, and the clip has an fps attribute, this fps will be used.
 
         codec
           Codec to use for image encoding. Can be any codec supported
@@ -270,7 +273,7 @@ class VideoClip(Clip):
             except KeyError:
                 raise ValueError("MoviePy couldn't find the codec associated "
                                  "with the filename. Provide the 'codec' parameter in "
-                                 "write_fideofile.")
+                                 "write_videofile.")
 
         if audio_codec is None:
             if (ext in ['ogv', 'webm']):
@@ -338,6 +341,7 @@ class VideoClip(Clip):
 
 
     @requires_duration
+    @use_clip_fps_by_default
     @convert_masks_to_RGB
     def write_images_sequence(self, nameformat, fps=None, verbose=True,
                               withmask=True):
@@ -381,9 +385,6 @@ class VideoClip(Clip):
 
         verbose_print(verbose, "MoviePy: Writing frames %s." % (nameformat))
 
-        if fps is None:
-            fps = self.fps
-
         tt = np.arange(0, self.duration, 1.0 / fps)
 
         filenames = []
@@ -401,6 +402,7 @@ class VideoClip(Clip):
 
 
     @requires_duration
+    @convert_masks_to_RGB
     def write_gif(self, filename, fps=None, program='ImageMagick',
                   opt="OptimizeTransparency", fuzz=1, verbose=True,
                   loop=0, dispose=False, colors=None, tempfiles=False):
@@ -482,7 +484,7 @@ class VideoClip(Clip):
         center = self.subclip(ta, tb).fx(fx, **kwargs)
         right = None if (tb is None) else self.subclip(t_start=tb)
 
-        clips = [c for c in [left, center, right] if c != None]
+        clips = [c for c in [left, center, right] if c is not None]
 
         # beurk, have to find other solution
         from moviepy.video.compositing.concatenate import concatenate_videoclips
@@ -880,7 +882,7 @@ class ImageClip(VideoClip):
         for attr in apply_to:
             if hasattr(self, attr):
                 a = getattr(self, attr)
-                if a != None:
+                if a is not None:
                     new_a = a.fl_image(image_func)
                     setattr(self, attr, new_a)
 
@@ -894,13 +896,13 @@ class ImageClip(VideoClip):
         (see Clip.fl_time).
 
         This method does nothing for ImageClips (but it may affect their
-        masks of their audios). The result is still an ImageClip.
+        masks or their audios). The result is still an ImageClip.
         """
 
         for attr in apply_to:
             if hasattr(self, attr):
                 a = getattr(self, attr)
-                if a != None:
+                if a is not None:
                     new_a = a.fl_time(time_func)
                     setattr(self, attr, new_a)
 
@@ -1032,7 +1034,7 @@ class TextClip(ImageClip):
             # use a file instead of a text.
             txt = "@%" + filename
 
-        if size != None:
+        if size is not None:
             size = ('' if size[0] is None else str(size[0]),
                     '' if size[1] is None else str(size[1]))
 
@@ -1041,18 +1043,18 @@ class TextClip(ImageClip):
                "-fill", color,
                "-font", font])
 
-        if fontsize != None:
+        if fontsize is not None:
             cmd += ["-pointsize", "%d" % fontsize]
-        if kerning != None:
+        if kerning is not None:
             cmd += ["-kerning", "%0.1f" % kerning]
-        if stroke_color != None:
+        if stroke_color is not None:
             cmd += ["-stroke", stroke_color, "-strokewidth",
                     "%.01f" % stroke_width]
-        if size != None:
+        if size is not None:
             cmd += ["-size", "%sx%s" % (size[0], size[1])]
-        if align != None:
+        if align is not None:
             cmd += ["-gravity", align]
-        if interline != None:
+        if interline is not None:
             cmd += ["-interline-spacing", "%d" % interline]
 
         if tempfilename is None:
@@ -1113,6 +1115,13 @@ class TextClip(ImageClip):
 
     @staticmethod
     def search(string, arg):
-      string = string.lower()
-      names_list = TextClip.list(arg)
-      return [name for name in names_list if string in name.lower()]
+        """ Returns the of all valid entries which contain ``string`` for the
+           argument ``arg`` of ``TextClip``, for instance
+
+           >>> # Find all the available fonts which contain "Courier"
+           >>> print ( TextClip.search('Courier', 'font') )
+ 
+        """
+        string = string.lower()
+        names_list = TextClip.list(arg)
+        return [name for name in names_list if string in name.lower()]
